.. pyeodh documentation master file, created by
   sphinx-quickstart on Fri Apr 12 12:38:56 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyeodh's documentation!
==================================

*pyeodh* is a Python client wrapping all EODH API endpoints. It aims to be lightweight and easy to use.

Installation
------------

*pyeodh* can be installed from PyPi with
   
   .. code-block::

    pip install pyeodh

Docker
------

There is also a docker image availabe based on python3-slim at `ghcr <https://github.com/EO-DataHub/pyeodh/pkgs/container/pyeodh>`_.


Usage
-----

See `example notebooks <https://github.com/EO-DataHub/pyeodh/tree/main/notebooks>`_ demonstrating interactions with EODH APIs.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
